@@ -4,15 +4,15 @@ use true;
 use experimental qw( signatures );
 use stable qw( postderef );
 
-package Data::Section::Pluggable 0.06 {
+package Data::Section::Pluggable 0.07 {
 
     # ABSTRACT: Read structured data from __DATA__
 
 
-    use Class::Tiny qw( package _formats _cache );
+    use Class::Tiny qw( package prefer_filesystem _formats _cache );
     use Exporter qw( import );
-    use Ref::Util qw( is_ref is_plain_hashref is_coderef is_plain_arrayref );
-    use MIME::Base64 qw( decode_base64 );
+    use Ref::Util qw( is_ref is_plain_hashref is_coderef is_plain_arrayref is_blessed_ref );
+    use MIME::Base64 qw( decode_base64 encode_base64 );
     use Path::Tiny 0.130 ();
     use Carp ();
 
@@ -33,6 +33,11 @@ package Data::Section::Pluggable 0.06 {
             my $package = caller 2;
             $self->package($package);
         }
+        if(defined $self->prefer_filesystem) {
+            unless(is_blessed_ref($self->prefer_filesystem) && $self->prefer_filesystem->isa('Path::Tiny')) {
+                $self->prefer_filesystem(Path::Tiny->new($self->prefer_filesystem)->absolute);
+            }
+        }
         $self->_formats({});
     }
 
@@ -116,6 +121,9 @@ package Data::Section::Pluggable 0.06 {
             } else {
                 $name = $name_encoding;
             }
+            if($self->prefer_filesystem && -f (my $path = $self->prefer_filesystem->child($name))) {
+                $content = $encoding ? encode_base64($path->slurp_raw) : $path->slurp_utf8;
+            }
             $all->{$name} = [ $content, $encoding ];
         }
 
@@ -210,7 +218,7 @@ Data::Section::Pluggable - Read structured data from __DATA__
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -285,6 +293,14 @@ where as this module returns C<undef>, in order to keep the return value more co
 The name of the package to read from C<__DATA__>.  If not specified, then
 the current package will be used.
 
+=head2 prefer_filesystem
+
+If provided, this is a directory containing files from where  content will be
+preferred over what is in the C<__DATA__> section, if available.  This file
+still must still exist in the C<__DATA__> section to be found. This can be
+useful to do local testing with files on the filesystem, but release a script
+or test a just one combined file.
+
 =head1 METHODS
 
 =head2 get_data_section
